# Upwork Automation CLI

A command-line tool to automate Upwork job search and application processes.

## Features

- Search for jobs based on custom criteria
- Filter jobs by keywords, budget, client history etc.
- Automate proposal submissions
- Track application status
- Save job searches and proposals

## Installation

```bash
npm install -g upwork-fetcher
```

## Usage

```bash
upwork-fetcher fetch -s "node.js,react" --limit 10
upwork-fetcher setup --client_id "123456" --client_secret "client_secret" --redirect_uri "redirect_uri"
```

## deployment instructions:

```
poetry version [patch | minor | major]
git tag <tag_name>
git add .
git commit -m ""
git push origin --tags
```
